@@ -13,7 +13,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 has timeout => (
@@ -151,15 +151,15 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
- use AnyEvent::WebSocket::Client;
+ use AnyEvent::WebSocket::Client 0.12;
  
  my $client = AnyEvent::WebSocket::Client->new;
  
- $client->connect("ws://localhost:1234")->cb(sub {
+ $client->connect("ws://localhost:1234/service")->cb(sub {
    my $connection = eval { shift->recv };
    if($@) {
      # handle error...
@@ -169,19 +169,22 @@ version 0.11
    $connection->send('a message');
    
    # recieve message from the websocket...
-   $connection->on_each_message(sub {
-     my $message = shift;
+   $connection->on(each_message => sub {
+     # $connection is the same connection object
+     # $message isa AnyEvent::WebSocket::Message
+     my($connection, $message) = @_;
      ...
    });
    
    # handle a closed connection...
-   $connection->on_finish(sub {
+   $connection->on(finish => sub {
+     # $connection is the same connection object
+     my($connection) = @_;
      ...
    });
 
    # close the connection (either inside or
    # outside another callback)
-   use AnyEvent::WebSocket::Client 0.10; # requires 0.10
    $connection->close;
  
  });
@@ -194,6 +197,11 @@ L<Protocol::WebSocket> rather than reinventing the wheel.  You could use
 L<AnyEvent> and L<Protocol::WebSocket> directly if you wanted finer grain
 control, but if that is not necessary then this class may save you some time.
 
+The recommended API was added to the L<AnyEvent::WebSocket::Connection>
+class with version 0.12, so it is recommended that you include that version
+when using this module.  The older API will continue to work for now with
+deprecation warnings.
+
 =head1 ATTRIBUTES
 
 =head2 timeout
@@ -241,6 +249,10 @@ L<AnyEvent::WebSocket::Connection>
 
 =item *
 
+L<AnyEvent::WebSocket::Message>
+
+=item *
+
 L<AnyEvent>
 
 =item *
