@@ -7,9 +7,12 @@ use Moo;
 use warnings NONFATAL => 'all';
 use Protocol::WebSocket::Frame;
 use Scalar::Util qw( weaken );
+use Encode ();
+use AnyEvent::WebSocket::Message;
+use Carp qw( croak carp );
 
 # ABSTRACT: WebSocket connection for AnyEvent
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 has _stream => (
@@ -24,7 +27,7 @@ has _handle => (
   weak_ref => 1,
 );
 
-foreach my $type (qw( each next finish ))
+foreach my $type (qw( each_message next_message finish ))
 {
   has "_${type}_cb" => (
     is       => 'ro',
@@ -38,7 +41,7 @@ sub BUILD
   my $self = shift;
   weaken $self;
   my $finish = sub {
-    $_->() for @{ $self->_finish_cb };
+    $_->($self) for @{ $self->_finish_cb };
   };
   $self->_handle->on_error($finish);
   $self->_handle->on_eof($finish);
@@ -47,12 +50,19 @@ sub BUILD
   
   $self->_stream->read_cb(sub {
     $frame->append($_[0]{rbuf});
-    while(defined(my $message = $frame->next))
+    while(defined(my $body = $frame->next_bytes))
     {
-      next if !$frame->is_text && !$frame->is_binary;
-      $_->($message) for @{ $self->_next_cb };
-      @{ $self->_next_cb } = ();
-      $_->($message) for @{ $self->_each_cb };
+      if($frame->is_text || $frame->is_binary)
+      {
+        my $message = AnyEvent::WebSocket::Message->new(
+          body   => $body,
+          opcode => $frame->opcode,
+        );
+      
+        $_->($self, $message) for @{ $self->_next_message_cb };
+        @{ $self->_next_message_cb } = ();
+        $_->($self, $message) for @{ $self->_each_message_cb };
+      }
     }
   });
 }
@@ -60,34 +70,43 @@ sub BUILD
 
 sub send
 {
-  my $self = shift;
-  $self->_handle->push_write(
-    Protocol::WebSocket::Frame->new(shift)->to_bytes
-  );
+  my($self, $message) = @_;
+  my $frame;
+  if(ref $message)
+  {
+    $DB::single = 1;
+    $frame = Protocol::WebSocket::Frame->new($message->body);
+    $frame->opcode($message->opcode);
+  }
+  else
+  {
+    $frame = Protocol::WebSocket::Frame->new($message);
+  }
+  $self->_handle->push_write($frame->to_bytes);
   $self;
 }
 
 
-sub on_each_message
+sub on
 {
-  my($self, $cb) = @_;
-  push @{ $self->_each_cb }, $cb;
-  $self;
-}
-
-
-sub on_next_message
-{
-  my($self, $cb) = @_;
-  push @{ $self->_next_cb }, $cb;
-  $self;
-}
-
-
-sub on_finish
-{
-  my($self, $cb) = @_;
-  push @{ $self->_finish_cb }, $cb;
+  my($self, $event, $cb) = @_;
+  
+  if($event eq 'next_message')
+  {
+    push @{ $self->_next_message_cb }, $cb;
+  }
+  elsif($event eq 'each_message')
+  {
+    push @{ $self->_each_message_cb }, $cb;
+  }
+  elsif($event eq 'finish')
+  {
+    push @{ $self->_finish_cb }, $cb;
+  }
+  else
+  {
+    croak "unrecongized event: $event";
+  }
   $self;
 }
 
@@ -100,6 +119,37 @@ sub close
   $self->_handle->push_shutdown;
 }
 
+
+sub on_each_message
+{
+  my($self, $cb) = @_;
+  carp "on_each_message is deprecated" if warnings::enabled('deprecated');
+  $self->on(each_message => sub {
+    $cb->(Encode::decode("UTF-8",pop->body));
+  });
+  $self;
+}
+
+
+sub on_next_message
+{
+  my($self, $cb) = @_;
+  carp "on_next_message is deprecated" if warnings::enabled('deprecated');
+  $self->on(next_message => sub {
+    $cb->(Encode::decode("UTF-8",pop->body));
+  });
+  $self;
+}
+
+
+sub on_finish
+{
+  my($self, $cb) = @_;
+  carp "on_finish is deprecated" if warnings::enabled('deprecated');
+  $self->on(finish => $cb);
+  $self;
+}
+
 1;
 
 __END__
@@ -112,7 +162,7 @@ AnyEvent::WebSocket::Connection - WebSocket connection for AnyEvent
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -120,20 +170,23 @@ version 0.11
  $connection->send('a message');
  
  # recieve message from the websocket...
- $connection->on_each_message(sub {
-   my $message = shift;
+ $connection->on(each_message => sub {
+   # $connection is the same connection object
+   # $message isa AnyEvent::WebSocket::Message
+   my($connection, $message) = @_;
    ...
  });
  
  # handle a closed connection...
- $connection->on_finish(sub {
+ $connection->on(finish => sub {
+   # $connection is the same connection object
+   my($connection) = @_;
    ...
  });
  
  # close an opened connection
  # (can do this either inside or outside of
  # a callback)
- use AnyEvent::WebSocket::Connection 0.10; # requires 0.10
  $connection->close;
 
 (See L<AnyEvent::WebSocket::Client> on how to create
@@ -158,28 +211,66 @@ much the same).
 
 =head2 $connection-E<gt>send($message)
 
-Send a message to the other side.
+Send a message to the other side.  C<$message> may either be a string
+(in which case a text message will be sent), or an instance of
+L<AnyEvent::WebSocket::Message>.
+
+=head2 $connection-E<gt>on($event => $cb)
+
+Register a callback to a particular event.
+
+For each event C<$connection> is the L<AnyEvent::WebSocket::Connection> and
+and C<$message> is an L<AnyEvent::WebSocket::Message> (if available).
+
+=head3 each_message
+
+ $cb->($connection, $message)
+
+Called each time a message is received from the WebSocket.
+
+=head3 next_message
+
+ $cb->($connection, $message)
+
+Called only for the next message received from the WebSocket.
+
+=head3 finish
+
+ $cb->($connection)
+
+Called when the connection is terminated
+
+=head3
+
+=head2 $connection-E<gt>close
+
+Close the connection.
+
+=head1 DEPRECATED METHODS
+
+The methods in this section are deprecated and may be removed from a
+future version of this class.  They should not be used for new code,
+and are only remain documented here to aid in understanding legacy
+code that use them.
 
 =head2 $connection-E<gt>on_each_message($cb)
 
 Register a callback to be called on each subsequent message received.
 The message itself will be passed in as the only parameter to the
 callback.
+The message is a decoded text string.
 
 =head2 $connection-E<gt>on_next_message($cb)
 
 Register a callback to be called the next message received.
 The message itself will be passed in as the only parameter to the
 callback.
+The message is a decoded text string.
 
 =head2 $connection-E<gt>on_finish($cb)
 
 Register a callback to be called when the connection is closed.
 
-=head2 $connection-E<gt>close
-
-Close the connection.
-
 =head1 SEE ALSO
 
 =over 4
@@ -190,8 +281,16 @@ L<AnyEvent::WebSocket::Client>
 
 =item *
 
+L<AnyEvent::WebSocket::Message>
+
+=item *
+
 L<AnyEvent>
 
+=item *
+
+L<RFC 6455 The WebSocket Protocol|http://tools.ietf.org/html/rfc6455>
+
 =back
 
 =cut
