@@ -2,12 +2,13 @@ package AnyEvent::WebSocket::Message;
 
 use strict;
 use warnings;
+use v5.10;
 use Moo;
+use warnings NONFATAL => 'all';
 use Encode ();
 
 # ABSTRACT: WebSocket message for AnyEvent
-our $VERSION = '0.51_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.12'; # VERSION
 
 
 has body => ( is => 'ro', required => 1 );
@@ -32,15 +33,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 AnyEvent::WebSocket::Message - WebSocket message for AnyEvent
 
 =head1 VERSION
 
-version 0.51_01
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -58,10 +57,8 @@ version 0.51_01
 
 =head1 DESCRIPTION
 
-Instances of this class represent a single WebSocket message.  They are
-the objects that come through from the other end of your
-L<AnyEvent::WebSocket::Connection> instance.  They can also be sent through
-that class using its C<send> method.
+Instances of this class represent a message passed through the WebSocket
+from the other end.
 
 =head1 ATTRIBUTES
 
@@ -75,39 +72,27 @@ The integer code for the type of message.
 
 =head1 METHODS
 
-=head2 decoded_body
-
- my $body = $message->decoded_body;
+=head2 $message-E<gt>decoded_body
 
 Returns the body decoded from UTF-8.
 
-=head2 is_text
-
- my $bool = $message->is_text;
+=head2 $message-E<gt>is_text
 
 True if the message is text.
 
-=head2 is_binary
-
- my $bool = $message->is_binary;
+=head2 $message-E<gt>is_binary
 
 True if the message is binary.
 
-=head2 is_close
-
- my $bool = $message->is_close;
+=head2 $message-E<gt>is_close
 
 True if the message is a close message.
 
-=head2 is_ping
-
- my $bool = $message->is_ping
+=head2 $message-E<gt>is_ping
 
 True if the message is a ping.
 
-=head2 is_pong
-
- my $bool = $message->is_pong;
+=head2 $message-E<gt>is_pong
 
 True if the message is a pong.
 
@@ -125,10 +110,6 @@ L<AnyEvent::WebSocket::Connection>
 
 =item *
 
-L<AnyEvent::WebSocket::Server>
-
-=item *
-
 L<AnyEvent>
 
 =item *
@@ -137,25 +118,15 @@ L<RFC 6455 The WebSocket Protocol|http://tools.ietf.org/html/rfc6455>
 
 =back
 
-=for stopwords Joaquín José
+=cut
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+author: Graham Ollis <plicease@cpan.org>
 
-Contributors:
+contributors:
 
-Toshio Ito (debug-ito, TOSHIOITO)
-
-José Joaquín Atria (JJATRIA)
-
-Kivanc Yazan (KYZN)
-
-Yanick Champoux (YANICK)
-
-Fayland Lam (FAYLAND)
-
-Daniel Kamil Kozar (xavery)
+Toshio Ito
 
 =head1 COPYRIGHT AND LICENSE
 
